@@ -7,7 +7,7 @@ import pandas as pd
 from s3fs import S3FileSystem
 
 from dateutil import parser as dateparser
-from datetime import datetime, timedelta
+from datetime import datetime, date, timedelta
 
 class DataSource(object):
     """
@@ -429,9 +429,10 @@ class Dataset(DataSource):
            list (dict): List of dictionaries (name, timestamp)
 
         """
-        if ((not isinstance(start, datetime))  or
-            ((end is not None) and (not isinstance(end, datetime)))):
-            raise Exception("Start or end is not a datetime")
+        if ((not isinstance(start, (datetime,date))) or
+            ((end is not None) and
+             (not isinstance(end, (datetime, date))))):
+            raise Exception("Start or end is not a datetime/date")
 
         # One day
         if end is None:
@@ -441,6 +442,7 @@ class Dataset(DataSource):
         if end < start:
             start, end = end, start
 
+
         func = self.match['generate']
         if isinstance(func,str):
             func = getattr(self, func)
@@ -498,10 +500,12 @@ class Dataset(DataSource):
         # Generate all possible <timestamp>: <name> combinations
         names = self.generate(start, end)
 
+        # names is a dict {'timestamp': '2021-02-02T13:24:11', 'name': '2021-02-02'}
+        names = [n['name'] for n in names]
         # Check if the name is in the names or in the range. The
         # latter is required if there are multiple runs in a given day
         #
-        return ((name in names.values()) or
+        return ((name in names) or
                 ((name >= min(names) and name <= max(names))))
 
     def match_content(self, fs, localdir, backupdir, dirname):
@@ -629,6 +633,37 @@ class Dataset(DataSource):
 
         return results
 
+    def read_data(self,
+                  start_date,
+                  end_date,
+                  filename,
+                  readfunc,
+                  name="default",
+                  params={},
+                  resolve={}):
+        """
+        Read a single dataset
+        """
+
+        dates = self.generate(start_date, end_date)
+        if len(dates) == 0:
+            raise Exception("No dates found")
+
+        # Get the path template...
+        path = self.get_path_by_name(name, resolve)
+
+        # Now compose all the dataframes...
+        _dfs = []
+        for dt in dates:
+            fullpath = os.path.join(path, dt['name'], filename)
+            df = readfunc(fullpath, params)
+            _dfs.append(df)
+
+        df = pd.concat(_dfs, ignore_index=True)
+        del _dfs
+
+        return df
+
 class Arg():
     """
     Dataset command argument
